#!/bin/sh
ORACLE_HOME=/u01/app/oracle/product/11.2.0/oracle/dbhome_1
export ORACLE_HOME
export PATH=$ORACLE_HOME/bin:$PATH
ORACLE_SID=emeralitprd; export ORACLE_SID
DP_DUMP=/u03/flash_recovery_area/DP_DUMP
expdp_log=/u03/flash_recovery_area/DP_DUMP/emeralitprd_daily_exp-$(date +%Y%m%d).log
date=$(date +%Y%m%d)

##REMOVE DUMPFILES AND LOGFILES#####################
find ${DP_DUMP} -name "*.log" -mtime +4 -exec rm {} \;
find ${DP_DUMP} -name "*.dmp" -mtime +4 -exec rm {} \;
find ${DP_DUMP} -name "*.gz" -mtime +4 -exec rm {} \;
find ${DP_DUMP} -name "refresh_*" -mtime +4 -exec rm -r {} \;

####BEGIN EXPORT######
echo ""
echo "Beginning Daily Export"
expdp system/oracle DIRECTORY=DP_DUMP FULL=y DUMPFILE=emeralitprd_daily_exp-$(date +%Y%m%d).dmp LOGFILE=emeralitprd_daily_exp-$(date +%Y%m%d).log

####Create GRANT, CONSTRAINT, SEQUENCE sql files for refresh
impdp \'/ as sysdba\' dumpfile=emeralitprd_daily_exp-$(date +%Y%m%d).dmp logfile=grant_emeralit.log schemas=NEBF directory=DP_DUMP CONTENT=METADATA_ONLY INCLUDE=grant sqlfile=grant_emeralit.sql
impdp \'/ as sysdba\' dumpfile=emeralitprd_daily_exp-$(date +%Y%m%d).dmp logfile=grant_emeralitprd.log schemas=NEBFPRD directory=DP_DUMP CONTENT=METADATA_ONLY INCLUDE=grant sqlfile=grant_emeralitprd.sql

impdp \'/ as sysdba\' dumpfile=emeralitprd_daily_exp-$(date +%Y%m%d).dmp logfile=constraint_emeralit.log schemas=NEBF directory=DP_DUMP CONTENT=METADATA_ONLY INCLUDE=constraint sqlfile=constraint_emeralit.sql
impdp \'/ as sysdba\' dumpfile=emeralitprd_daily_exp-$(date +%Y%m%d).dmp logfile=constraint_emeralitprd.log schemas=NEBFPRD directory=DP_DUMP CONTENT=METADATA_ONLY INCLUDE=constraint sqlfile=constraint_emeralitprd.sql

impdp \'/ as sysdba\' dumpfile=emeralitprd_daily_exp-$(date +%Y%m%d).dmp logfile=sequence_emeralit.log schemas=NEBF directory=DP_DUMP CONTENT=METADATA_ONLY INCLUDE=sequence sqlfile=sequence_emeralit.sql
impdp \'/ as sysdba\' dumpfile=emeralitprd_daily_exp-$(date +%Y%m%d).dmp logfile=sequence_emeralitprd.log schemas=NEBFPRD directory=DP_DUMP CONTENT=METADATA_ONLY INCLUDE=sequence sqlfile=sequence_emeralitprd.sql


###Moving the GRANT, CONSTRAINT, SEQUENCE script###
mkdir $DP_DUMP/refresh_$date
mv $DP_DUMP/grant*.* $DP_DUMP/refresh_$date
mv $DP_DUMP/constraint*.* $DP_DUMP/refresh_$date
mv $DP_DUMP/sequence*.* $DP_DUMP/refresh_$date


###Generate .PAR file for NEBF###
echo dumpfile=emeralitprd_daily_exp-$date.dmp > $DP_DUMP/refresh_$date/emeralit.par
echo directory=DP_DUMP >> $DP_DUMP/refresh_$date/emeralit.par
echo logfile=emeralit_import.log >> $DP_DUMP/refresh_$date/emeralit.par
echo parallel=5 >> $DP_DUMP/refresh_$date/emeralit.par
echo table_exists_action=replace >> $DP_DUMP/refresh_$date/emeralit.par

emeralit_tables=`sqlplus -s / as sysdba <<ENDSQL
set head off;
set feedback off;
set pagesize 0 linesize 200 trimspool on;
select owner ||'.'|| table_name || ','  from dba_tables where owner='NEBF' order by table_name;
exit;
ENDSQL
`
echo "TABLES="$emeralit_tables >> $DP_DUMP/refresh_$date/emeralit.par
sed '$ s/,$//' $DP_DUMP/refresh_$date/emeralit.par > $DP_DUMP/refresh_$date/emeralit_buffer.par
mv $DP_DUMP/refresh_$date/emeralit_buffer.par $DP_DUMP/refresh_$date/emeralit.par


###Generate .PAR file for emeralitprd###
echo dumpfile=emeralitprd_daily_exp-$date.dmp > $DP_DUMP/refresh_$date/emeralitprd.par
echo directory=DP_DUMP >> $DP_DUMP/refresh_$date/emeralitprd.par
echo logfile=emeralitprd_import.log >> $DP_DUMP/refresh_$date/emeralitprd.par
echo parallel=5 >> $DP_DUMP/refresh_$date/emeralitprd.par
echo table_exists_action=replace >> $DP_DUMP/refresh_$date/emeralitprd.par

emeralitprd_tables=`sqlplus -s / as sysdba <<ENDSQL
set head off;
set feedback off;
set pagesize 0 linesize 200 trimspool on;
select owner ||'.'|| table_name || ','  from dba_tables where owner='NEBFPRD' order by table_name;
exit;
ENDSQL
`

echo "TABLES="$emeralitprd_tables >> $DP_DUMP/refresh_$date/emeralitprd.par
sed '$ s/,$//' $DP_DUMP/refresh_$date/emeralitprd.par > $DP_DUMP/refresh_$date/emeralitprd_buffer.par
mv $DP_DUMP/refresh_$date/emeralitprd_buffer.par $DP_DUMP/refresh_$date/emeralitprd.par


##Check for errors in logfile###
error_chk=`grep -c "ORA-" ${expdp_log}`
if [ ${error_chk} -gt 4 ]
then
echo "NEBF Alert: Daily Export has errors."
mailx -s "Proactive:NEBF DAILY EXPORT completed with errors" proactive_support@emeralit.com < ${DP_DUMP}/emeralitprd_daily_exp-$(date +%Y%m%d).log
else
gzip /u03/flash_recovery_area/DP_DUMP/emeralitprd_daily_exp-$(date +%Y%m%d).dmp

#--- Create log size file ---
ls -ltr $DP_DUMP/emeralitprd_daily_exp-$date.dmp.gz | awk '{print $9, $5}' > $DP_DUMP/refresh_$date/source_filesize_$date.log
ls -ltr $DP_DUMP/refresh_$date/*.sql | awk '{print $9, $5}' >> $DP_DUMP/refresh_$date/source_filesize_$date.log
ls -ltr $DP_DUMP/refresh_$date/*.par | awk '{print $9, $5}' >> $DP_DUMP/refresh_$date/source_filesize_$date.log

mailx -s "Informative:NEBF:`hostname`:Daily expdp backup has been completed and zipped." support@emeralit.com < ${DP_DUMP}/emeralitprd_daily_exp-$(date +%Y%m%d).log
fi;